| triangle_mom | R Documentation |
Triangle distribution method of moments estimate
triangle_mom(x, na.rm = FALSE, type = 1)
x |
triangle distribution sample |
na.rm |
whether to remove NA samples. Default is FALSE. |
type |
the type of method of moments. Type 1 uses the min and max. Type2 minimizes the distance from the calculated mean, variance, and skewness to the sample mean, variance, and skewness |
a named vector of the parameter estimates
set.seed(1204)
x <- rtriangle(20, 0, 2, 1.5)
triangle_mom(x)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.